import macondo.mjada.*;
import macondo.mjada.collections.*;
import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 *	A simple chat application build upon MAK collections
 *	coordination features.
 */

public class ChatClient implements ActionListener, Runnable {
	private Space 	space;
	private TupleCollection co;
	private boolean	flag = true;
	private String	userName;
	private static final Tuple pattern = new Tuple(String.class, String.class, String.class);
	// GUI stuff
	Frame		frame;
	TextArea	textarea;
	TextField	msg_tf;
	TextField	user_name_tf;
	Button		button;
	int			width = 400,
				height = 400;
	
	public static void main(String[] args) {
		ChatClient client = new ChatClient();
		client.parseCmdLine(args);
		client.initGUI();
		new Thread(client).start();
	}
	
	public void parseCmdLine(String[] args) {
		String	host = "localhost";
		int		port = MJada.DEFAULT_PORT;
		
		for(int i=0;i<args.length;i++) {
			if (args[i].equals("-r")) {
				if (i+1 < args.length) {
					++i;
					host = args[i];
				} else {
					System.out.println("Wrong number of parameters. Exiting.");
					System.exit(0);
				}
				
				if (i+1 < args.length) {
					++i;
					try {
						port = Integer.parseInt(args[i]);
					} catch (NumberFormatException nfe) {
						port = MJada.DEFAULT_PORT;
					}
				}

			} else if (args[i].equals("-h") || args[i].equals("-help")) {
				System.out.println("Usage: java ChatClient [-r [hostname [port]]]");
				System.exit(0);
			}
		}

	
		space = new SpaceClient(host, port);
		co = new TupleCollection(space, pattern);
	}
	
	public void initGUI() {
		frame = new Frame("Chat");
		frame.setLayout(null);
		
		textarea = new TextArea(80,20);
		textarea.setEditable(false);
		
		msg_tf = new TextField(80);
		user_name_tf = new TextField(8);
		button = new Button("Submit");
		button.addActionListener(this);
		frame.setLayout(null);
		frame.setSize(width,height);
		
		frame.add(textarea);
		textarea.setBounds(5,25,380,200);
		frame.add(msg_tf);
		msg_tf.setBounds(10,240,240,30);
		frame.add(user_name_tf);
		user_name_tf.setBounds(10,320,80,30);
		frame.add(button);
		button.setBounds(270,240,100,30);
		
		frame.pack();
		frame.show();
	}
	
	public void run() {
		messageLoop();
	}
	
	public void messageLoop() {
		int msg_index = 0;
		Tuple 	result;
		Result	res;
		String	type, from, msg;
		
		TupleIterator iterator = co.readIterator();
		
		userName = user_name_tf.getText();
		while(flag) {
			result = iterator.nextTuple();
			type = (String)result.getItem(0);
			from = (String)result.getItem(1);
			
			if ( type.equals("_msg") ) {
				msg = (String)result.getItem(2);
				textarea.append(from+":" + space.getSpaceName() + "> " + msg + "\n");
			} else if ( type.equals("_join") && from.equals(userName) ) {
				msg = (String)result.getItem(2);
				space.join(msg);
				System.out.println("space name is now "+space.getSpaceName());
				co = new TupleCollection(space, pattern);
				iterator = co.readIterator();
			} else if ( type.equals("_leave") && from.equals(userName) ) {
				space.leave();
				System.out.println("space name is now "+space.getSpaceName());
				co = new TupleCollection(space, pattern);
				iterator = co.readIterator();
			}
		}
	}
	
	public void actionPerformed(ActionEvent e) {
		String	source = e.getActionCommand(),
				msg = msg_tf.getText();
		msg_tf.setText("");
		
		if (userName.equals("")) {
			userName = user_name_tf.getText();
		}
		
		if (source.equals("Submit")) {
			if (msg.startsWith("join")) {
				co.add(new Tuple("_join", user_name_tf.getText(), msg.substring(5)));
			} else if (msg.equals("leave")) {
				co.add(new Tuple("_leave", user_name_tf.getText(), String.class));
			} else { // normal message handling
				co.add(new Tuple("_msg", user_name_tf.getText(), msg));
			}
		}
		
	}
	
}
