package macondo.mak;

/**
 *	This class represents the result of a migration. Its main usage
 *	is as a synchronization medium between place threads.
 *
 *	@author		Andrea Giovannini
 *	@version	beta
 */

public class MigrationResult {

	private TransportException	e;
	private int					result;
	private Object				lock;
	
	private static final int OK = 0;
	private static final int KO = 1;
	private static final int NULL = 2;
	
	// Constructors ------------------------------------------------------

	/**
	 *	Default constructor.
	 */
	public MigrationResult() {
		result = NULL;
	}

	// Public Methods ----------------------------------------------------

	public synchronized void setException(TransportException e) {
		result = KO;
		this.e = e;
		notifyAll();
	}
	
	public TransportException getException() {
		return e;
	}
	
	public synchronized void setSuccess() {
		result = OK;
		notifyAll();
	}
	
	public synchronized boolean success() {
		while(true) {
			if (result != NULL) {
				break;
			}
			try {
				wait();
			} catch (InterruptedException e) {}
		}
		
		return (result == OK);
	}
	
}