package macondo.mjada;

import jada.Jada;

/**
 *	This class defines some constants and utility methods.
 *	This class cannot be instantiated.
 *
 *	@author		Andrea Giovannini
 *	@version	beta
 */

public final class MJada {

	/**
	 *	This is the default port number used by the <code>SpaceServer</code>
	 *	object.
	 *
	 *	@see	SpaceServer
	 */
	public final static int DEFAULT_PORT = jada.JadaNetConst.DEFAULT_PORT;

	// Constructor -------------------------------------------------------
	// Don't let anyone instantiate this class.
	private MJada() {}
	
	// Public Methods ----------------------------------------------------

	/**
	 *	Adds a new <code>GlobalSerializer</code> object to the MJada
	 *	run time for the specified class.
	 *
	 *	@param	aclass	a class.
	 *	@see	GlobalSerializer
	 */	
	public static void addSerializer(Class aclass) {
		Jada.addSerializer(aclass, new GlobalSerializer());
	}
	
	/**
	 *	Removes a serializer, if added, for the specified class.
	 *
	 *	@param	aclass	a class.
	 *	@see	GlobalSerializer
	 */
	public static void removeSerializer(Class aclass) {
		Jada.removeSerializer(aclass);
	}

}