package macondo.mjada.collections;

import macondo.mjada.*;
import jada.ObjectSpace;

/**
 *	<code>InIterator</code> is a tuple iterator that withdrawn
 *	a sequence of tuples.
 *
 *	@see	TupleIterator
 */

public class InIterator implements TupleIterator {

	private ObjectSpace		objSpace;
	private SpaceName		spaceName;
	private Token			currToken;
	private Tuple			pattern;
	
	// Constructor -------------------------------------------------------
	
	/**
	 *	Builds a new <code>InIterator</code> in order to withdraw tuples
	 *	with the specifed pattern from the specified tuple space.
	 *
	 *	@param	space	the tuple space.
	 *	@param	pattern	the tuple template.
	 */
	public InIterator(Space space, Tuple pattern) {
		this.objSpace = space.getObjectSpace();
		this.spaceName = space.getSpaceName();
		this.currToken = new Token();
		this.pattern = pattern;
	}
	
	// Public Methods ----------------------------------------------------
	
	/**
	 *	TupleIterator interface method.
	 *	Returns the next tuple in this collection. The tuple is also
	 *	withdrawn from the collection. If no tuple is available
	 *	blocks waiting for a corresponding insertion.
	 *
	 *	@return	the next tuple in this collection.
	 */
	public Tuple nextTuple() {
		Tuple	tmp = null,
				result = null;
		
		tmp = (Tuple)objSpace.in( new Tuple(spaceName, currToken, pattern) );
		currToken.advance();
		result = (Tuple)tmp.getItem(2);
		return result;
	}
	
}
