package macondo.mjada.collections;

import java.io.*;
import jada.JadaItem;
import macondo.mjada.ItemNotStreamableException;

/**
 *	A <code>Token</code> object can be used
 *	to define an order on a collection of tuples. Be careful that tuples
 *	are not directly compared, but this object is used instead.
 *
 *	@author		Andrea Giovannini
 *	@version	beta
 */

public class Token implements JadaItem {
	
	private int token;
	
	// Constructor -------------------------------------------------------
	
	/**
	 *	Builds a new <code>Token</code> object.
	 */
	public Token() {
		this.token = 0;
	}
	
	// Public Methods ----------------------------------------------------

	/**
	 *	Advance this token.
	 */
	public void advance() {
		++token;
	}
	
	
	// JadaItem interface methods
	
	public void dumpItem(OutputStream os) throws ItemNotStreamableException,
			IOException {
		DataOutputStream output = new DataOutputStream( os );
		output.writeInt( token );
	}
	
	public void buildItem(InputStream is) throws ItemNotStreamableException,
			IOException {
		DataInputStream input = new DataInputStream(is);
		token = input.readInt();
	}
	
	public void cloneItem(Object source) {
		if ( !(source instanceof Token) ) {
			return;
		}
		Token tokenObject = (Token)source;
		token = tokenObject.token;
	}
	
	public boolean matchesItem(JadaItem match) {
		if ( !(match instanceof Token) ) {
			return false;
		}
		
		Token	tokenObject = (Token)match;
		
		return ( token == tokenObject.token );
	}
}
